# The character used to split date strings when parsing dates
# Default is hyphen (-) for dates like '2023-12-31'
# Can be changed using set_date_spliter() to support other formats like '2023/12/31'
date_spliter = '-'


